pub fn apply_cli_provider_arg_override(
cfg: &mut AppConfig,
provider_arg: Option<&str>,
) -> EffectiveLlmConfigExpand description
Apply a CLI --provider argument to the config.
This function does not persist any changes to disk.
pub fn apply_cli_provider_arg_override(
cfg: &mut AppConfig,
provider_arg: Option<&str>,
) -> EffectiveLlmConfigApply a CLI --provider argument to the config.
This function does not persist any changes to disk.