pub fn is_known_llm_provider(provider: &str) -> boolExpand description
Returns true when provider matches one of the KNOWN_LLM_PROVIDERS
(case-insensitive comparison).
pub fn is_known_llm_provider(provider: &str) -> boolReturns true when provider matches one of the KNOWN_LLM_PROVIDERS
(case-insensitive comparison).