pub fn apply_cli_model_arg_overrides(
cfg: &mut AppConfig,
model_arg: Option<&str>,
) -> EffectiveLlmConfigExpand description
Apply a CLI --model argument to the config.
The CLI supports either:
"provider:model"(e.g."openai:gpt-4o") to override both provider and model"model"(e.g."claude-3-5-sonnet-20241022") to override the model for the currently selected provider
This function does not persist any changes to disk.